@@ -1,9 +1,10 @@
 /*
- * Copyright 2001-2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -22,19 +23,28 @@ import java.io.OutputStream;
 
 /**
  * Utility code for dealing with different endian systems.
- * <br>
- * Origin of code: Apache Avalon (Excalibur)
+ * <p>
+ * Different computer architectures adopt different conventions for
+ * byte ordering. In so-called "Little Endian" architectures (eg Intel),
+ * the low-order byte is stored in memory at the lowest address, and
+ * subsequent bytes at higher addresses. For "Big Endian" architectures
+ * (eg Motorola), the situation is reversed.
+ * This class helps you solve this incompatability.
+ * <p>
+ * Origin of code: Excalibur
  *
  * @author <a href="mailto:peter@apache.org">Peter Donald</a>
- * @version CVS $Revision: 1.13 $ $Date: 2004/02/23 04:35:59 $
+ * @version $Id: EndianUtils.java 491359 2006-12-31 01:08:34Z ggregory $
+ * @see org.apache.commons.io.input.SwappedDataInputStream
  */
-public final class EndianUtils
-{
+public class EndianUtils {
 
     /**
      * Instances should NOT be constructed in standard programming.
      */
-    public EndianUtils() { }
+    public EndianUtils() {
+        super();
+    }
 
     // ========================================== Swapping routines
 
@@ -43,9 +53,8 @@ public final class EndianUtils
      * @param value value to convert
      * @return the converted value
      */
-    public static short swapShort( short value )
-    {
-        return (short)( ( ( ( value >> 0 ) & 0xff ) << 8 ) +
+    public static short swapShort(short value) {
+        return (short) ( ( ( ( value >> 0 ) & 0xff ) << 8 ) +
             ( ( ( value >> 8 ) & 0xff ) << 0 ) );
     }
 
@@ -54,8 +63,7 @@ public final class EndianUtils
      * @param value value to convert
      * @return the converted value
      */
-    public static int swapInteger( int value )
-    {
+    public static int swapInteger(int value) {
         return
             ( ( ( value >> 0 ) & 0xff ) << 24 ) +
             ( ( ( value >> 8 ) & 0xff ) << 16 ) +
@@ -68,8 +76,7 @@ public final class EndianUtils
      * @param value value to convert
      * @return the converted value
      */
-    public static long swapLong( long value )
-    {
+    public static long swapLong(long value) {
         return
             ( ( ( value >> 0 ) & 0xff ) << 56 ) +
             ( ( ( value >> 8 ) & 0xff ) << 48 ) +
@@ -86,8 +93,7 @@ public final class EndianUtils
      * @param value value to convert
      * @return the converted value
      */
-    public static float swapFloat( float value )
-    {
+    public static float swapFloat(float value) {
         return Float.intBitsToFloat( swapInteger( Float.floatToIntBits( value ) ) );
     }
 
@@ -96,8 +102,7 @@ public final class EndianUtils
      * @param value value to convert
      * @return the converted value
      */
-    public static double swapDouble( double value )
-    {
+    public static double swapDouble(double value) {
         return Double.longBitsToDouble( swapLong( Double.doubleToLongBits( value ) ) );
     }
 
@@ -110,8 +115,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @param value value to write
      */
-    public static void writeSwappedShort( byte[] data, int offset, short value )
-    {
+    public static void writeSwappedShort(byte[] data, int offset, short value) {
         data[ offset + 0 ] = (byte)( ( value >> 0 ) & 0xff );
         data[ offset + 1 ] = (byte)( ( value >> 8 ) & 0xff );
     }
@@ -123,23 +127,21 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static short readSwappedShort( byte[] data, int offset )
-    {
+    public static short readSwappedShort(byte[] data, int offset) {
         return (short)( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
             ( ( data[ offset + 1 ] & 0xff ) << 8 ) );
     }
 
     /**
-     * Reads an unsigned short (16-bit) value from a byte array at a given 
-     * offset. The value is converted to the opposed endian system while 
+     * Reads an unsigned short (16-bit) value from a byte array at a given
+     * offset. The value is converted to the opposed endian system while
      * reading.
      * @param data source byte array
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static int readSwappedUnsignedShort( byte[] data, int offset )
-    {
-        return (int)( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
+    public static int readSwappedUnsignedShort(byte[] data, int offset) {
+        return ( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
             ( ( data[ offset + 1 ] & 0xff ) << 8 ) );
     }
 
@@ -150,8 +152,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @param value value to write
      */
-    public static void writeSwappedInteger( byte[] data, int offset, int value )
-    {
+    public static void writeSwappedInteger(byte[] data, int offset, int value) {
         data[ offset + 0 ] = (byte)( ( value >> 0 ) & 0xff );
         data[ offset + 1 ] = (byte)( ( value >> 8 ) & 0xff );
         data[ offset + 2 ] = (byte)( ( value >> 16 ) & 0xff );
@@ -165,25 +166,23 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static int readSwappedInteger( byte[] data, int offset )
-    {
-        return (int)( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
+    public static int readSwappedInteger(byte[] data, int offset) {
+        return ( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
             ( ( data[ offset + 1 ] & 0xff ) << 8 ) +
             ( ( data[ offset + 2 ] & 0xff ) << 16 ) +
             ( ( data[ offset + 3 ] & 0xff ) << 24 ) );
     }
 
     /**
-     * Reads an unsigned integer (32-bit) value from a byte array at a given 
-     * offset. The value is converted to the opposed endian system while 
+     * Reads an unsigned integer (32-bit) value from a byte array at a given
+     * offset. The value is converted to the opposed endian system while
      * reading.
      * @param data source byte array
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static long readSwappedUnsignedInteger( byte[] data, int offset )
-    {
-        return (long)( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
+    public static long readSwappedUnsignedInteger(byte[] data, int offset) {
+        return ( ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
             ( ( data[ offset + 1 ] & 0xff ) << 8 ) +
             ( ( data[ offset + 2 ] & 0xff ) << 16 ) +
             ( ( data[ offset + 3 ] & 0xff ) << 24 ) );
@@ -196,8 +195,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @param value value to write
      */
-    public static void writeSwappedLong( byte[] data, int offset, long value )
-    {
+    public static void writeSwappedLong(byte[] data, int offset, long value) {
         data[ offset + 0 ] = (byte)( ( value >> 0 ) & 0xff );
         data[ offset + 1 ] = (byte)( ( value >> 8 ) & 0xff );
         data[ offset + 2 ] = (byte)( ( value >> 16 ) & 0xff );
@@ -215,19 +213,18 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static long readSwappedLong( byte[] data, int offset )
-    {
-        long low = (long)( 
+    public static long readSwappedLong(byte[] data, int offset) {
+        long low = 
             ( ( data[ offset + 0 ] & 0xff ) << 0 ) +
             ( ( data[ offset + 1 ] & 0xff ) << 8 ) +
             ( ( data[ offset + 2 ] & 0xff ) << 16 ) +
-            ( ( data[ offset + 3 ] & 0xff ) << 24 ) );
-        long high = (long)(
+            ( ( data[ offset + 3 ] & 0xff ) << 24 );
+        long high = 
             ( ( data[ offset + 4 ] & 0xff ) << 0 ) +
             ( ( data[ offset + 5 ] & 0xff ) << 8 ) +
             ( ( data[ offset + 6 ] & 0xff ) << 16 ) +
-            ( ( data[ offset + 7 ] & 0xff ) << 24 ) );
-        return low + (high << 32);
+            ( ( data[ offset + 7 ] & 0xff ) << 24 );
+        return (high << 32) + (0xffffffffL & low); 
     }
 
     /**
@@ -237,8 +234,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @param value value to write
      */
-    public static void writeSwappedFloat( byte[] data, int offset, float value )
-    {
+    public static void writeSwappedFloat(byte[] data, int offset, float value) {
         writeSwappedInteger( data, offset, Float.floatToIntBits( value ) );
     }
 
@@ -249,8 +245,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static float readSwappedFloat( byte[] data, int offset )
-    {
+    public static float readSwappedFloat(byte[] data, int offset) {
         return Float.intBitsToFloat( readSwappedInteger( data, offset ) );
     }
 
@@ -261,8 +256,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @param value value to write
      */
-    public static void writeSwappedDouble( byte[] data, int offset, double value )
-    {
+    public static void writeSwappedDouble(byte[] data, int offset, double value) {
         writeSwappedLong( data, offset, Double.doubleToLongBits( value ) );
     }
 
@@ -273,8 +267,7 @@ public final class EndianUtils
      * @param offset starting offset in the byte array
      * @return the value read
      */
-    public static double readSwappedDouble( byte[] data, int offset )
-    {
+    public static double readSwappedDouble(byte[] data, int offset) {
         return Double.longBitsToDouble( readSwappedLong( data, offset ) );
     }
 
@@ -285,7 +278,7 @@ public final class EndianUtils
      * @param value value to write
      * @throws IOException in case of an I/O problem
      */
-    public static void writeSwappedShort( OutputStream output, short value )
+    public static void writeSwappedShort(OutputStream output, short value)
         throws IOException
     {
         output.write( (byte)( ( value >> 0 ) & 0xff ) );
@@ -299,7 +292,7 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static short readSwappedShort( InputStream input )
+    public static short readSwappedShort(InputStream input)
         throws IOException
     {
         return (short)( ( ( read( input ) & 0xff ) << 0 ) +
@@ -313,13 +306,13 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static int readSwappedUnsignedShort( InputStream input )
+    public static int readSwappedUnsignedShort(InputStream input)
         throws IOException
     {
         int value1 = read( input );
         int value2 = read( input );
 
-        return (int)( ( ( value1 & 0xff ) << 0 ) +
+        return ( ( ( value1 & 0xff ) << 0 ) +
             ( ( value2 & 0xff ) << 8 ) );
     }
 
@@ -330,7 +323,7 @@ public final class EndianUtils
      * @param value value to write
      * @throws IOException in case of an I/O problem
      */
-    public static void writeSwappedInteger( OutputStream output, int value )
+    public static void writeSwappedInteger(OutputStream output, int value)
         throws IOException
     {
         output.write( (byte)( ( value >> 0 ) & 0xff ) );
@@ -346,7 +339,7 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static int readSwappedInteger( InputStream input )
+    public static int readSwappedInteger(InputStream input)
         throws IOException
     {
         int value1 = read( input );
@@ -354,10 +347,10 @@ public final class EndianUtils
         int value3 = read( input );
         int value4 = read( input );
 
-        return (int)( ( ( value1 & 0xff ) << 0 ) +
+        return ( ( value1 & 0xff ) << 0 ) +
             ( ( value2 & 0xff ) << 8 ) +
             ( ( value3 & 0xff ) << 16 ) +
-            ( ( value4 & 0xff ) << 24 ) );
+            ( ( value4 & 0xff ) << 24 );
     }
 
     /**
@@ -367,7 +360,7 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static long readSwappedUnsignedInteger( InputStream input )
+    public static long readSwappedUnsignedInteger(InputStream input)
         throws IOException
     {
         int value1 = read( input );
@@ -375,10 +368,10 @@ public final class EndianUtils
         int value3 = read( input );
         int value4 = read( input );
 
-        return (long)( ( ( value1 & 0xff ) << 0 ) +
+        return ( ( value1 & 0xff ) << 0 ) +
             ( ( value2 & 0xff ) << 8 ) +
             ( ( value3 & 0xff ) << 16 ) +
-            ( ( value4 & 0xff ) << 24 ) );
+            ( ( value4 & 0xff ) << 24 );
     }
 
     /**
@@ -388,7 +381,7 @@ public final class EndianUtils
      * @param value value to write
      * @throws IOException in case of an I/O problem
      */
-    public static void writeSwappedLong( OutputStream output, long value )
+    public static void writeSwappedLong(OutputStream output, long value)
         throws IOException
     {
         output.write( (byte)( ( value >> 0 ) & 0xff ) );
@@ -408,11 +401,13 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static long readSwappedLong( InputStream input )
+    public static long readSwappedLong(InputStream input)
         throws IOException
     {
         byte[] bytes = new byte[8];
-        input.read( bytes );
+        for ( int i=0; i<8; i++ ) {
+            bytes[i] = (byte) read( input );
+        }
         return readSwappedLong( bytes, 0 );
     }
 
@@ -423,7 +418,7 @@ public final class EndianUtils
      * @param value value to write
      * @throws IOException in case of an I/O problem
      */
-    public static void writeSwappedFloat( OutputStream output, float value )
+    public static void writeSwappedFloat(OutputStream output, float value)
         throws IOException
     {
         writeSwappedInteger( output, Float.floatToIntBits( value ) );
@@ -436,7 +431,7 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static float readSwappedFloat( InputStream input )
+    public static float readSwappedFloat(InputStream input)
         throws IOException
     {
         return Float.intBitsToFloat( readSwappedInteger( input ) );
@@ -449,7 +444,7 @@ public final class EndianUtils
      * @param value value to write
      * @throws IOException in case of an I/O problem
      */
-    public static void writeSwappedDouble( OutputStream output, double value )
+    public static void writeSwappedDouble(OutputStream output, double value)
         throws IOException
     {
         writeSwappedLong( output, Double.doubleToLongBits( value ) );
@@ -462,19 +457,24 @@ public final class EndianUtils
      * @return the value just read
      * @throws IOException in case of an I/O problem
      */
-    public static double readSwappedDouble( InputStream input )
+    public static double readSwappedDouble(InputStream input)
         throws IOException
     {
         return Double.longBitsToDouble( readSwappedLong( input ) );
     }
 
-    private static int read( InputStream input )
+    /**
+     * Reads the next byte from the input stream.
+     * @param input  the stream
+     * @return the byte
+     * @throws IOException if the end of file is reached
+     */
+    private static int read(InputStream input)
         throws IOException
     {
         int value = input.read();
 
-        if( -1 == value )
-        {
+        if( -1 == value ) {
             throw new EOFException( "Unexpected EOF reached" );
         }
 
